Rombus: Helps you qucikly and easily compute slow and complex models
====================================================================

This project is being developed in the course of delivering the RSmith_2022B ADACS Merit Allocation Program project.
